@@ -72,7 +72,9 @@ Configuration options:\n\
 -5 \tsocks5testmethod\n\
 -4 \tsocks4testmethod\n\
 -l \tlogfilename\n\
--i \tproxyknifein, the proxylist file used as input of proxyknife.\n\
+-I \tproxyknifeintype, the type of proxylist(local file or url)\n\
+-i \tproxyknifein, the proxylist file or url used as input of proxyknife.\n\
+\t'-' meanings stdin.\n\
 -o \tproxyknifeout, the file which proxyknife output result to. \n")
 ,VERSION);
 }
@@ -101,7 +103,7 @@ READCONF (int argc, char **argv)
   int set_threads = 0, set_checksite = 0, set_key = 0, set_logfilename = 0;
   int set_user_agent = 0, set_myconreplysize = 0, set_testconreplysize = 0;
   int set_testtagreplysize = 0, set_rcvtimeo = 0, set_sndtimeo = 0;
-  int set_proxyknifein = 0,set_proxyknifeout=0;
+  int set_proxyknifein = 0,set_proxyknifeout=0,set_proxyknifeintype = 0;
 
   struct hostent *h;
 
@@ -125,10 +127,12 @@ READCONF (int argc, char **argv)
   /* init inputfile ,outputfile */
   proxyknife_in = NULL;
   proxyknife_out = NULL;
+  proxyknife_in_buffer = NULL;
+  proxyknife_in_type = IN_FILE;
 
   while(1){
           c = getopt_long(argc,argv,
-                          "Vf:i:o:t:g:m:p:h:u:s:c:k:r:n:S:T:G:H:5:4:l:",
+                          "Vf:i:I:o:t:g:m:p:h:u:s:c:k:r:n:S:T:G:H:5:4:l:",
                           long_options,&option_index);
           if(c == -1)
                   break;
@@ -158,6 +162,10 @@ _("Jia Wang")
 		  case 'i':
                           optstr(optarg,&proxyknife_in,&set_proxyknifein);
                           break;
+          case 'I': 
+                          optint(optarg,&proxyknife_in_type,
+                                          &set_proxyknifeintype);
+                          break;
                   case 'o':
                           optstr(optarg,&proxyknife_out,&set_proxyknifeout);
                           break;
@@ -321,6 +329,8 @@ _("Jia Wang")
              &set_socks4testmethod)
 	    || !readstr (line, "logfilename=", &(logfilename),
 			 &set_logfilename)
+        || !readint (line,"proxyknifeintype=", &(proxyknife_in_type),
+                        &set_proxyknifeintype)
         || !readstr (line, "proxyknifein=",&(proxyknife_in),&set_proxyknifein)
         || !readstr (line, "proxyknifeout=",&(proxyknife_out),&set_proxyknifeout);
 	}
@@ -456,7 +466,12 @@ _("Jia Wang")
 
   /* If no NULL options or NULL configuration lines */
   if( proxyknife_in == NULL){
+          if( proxyknife_in_type == IN_HTTP ){
+            optstr(PROXYKNIFE_DEFAULT_LISTSITE,
+                            &proxyknife_in,&set_proxyknifein);
+          }else {
           optstr(PROXYKNIFE_IN,&proxyknife_in,&set_proxyknifein);
+          }
   }
   if( proxyknife_out == NULL){
           optstr(PROXYKNIFE_OUT,&proxyknife_out,&set_proxyknifeout);
@@ -478,13 +493,14 @@ _("Jia Wang")
 	  "\tsndtimeo=%d\n"
 	  "\ttestconreplysize=%d\n"
 	  "\ttesttagreplysize=%d\n"
+      "\tproxyknife_in_type=%d\n"
       "\tproxyknife_in=%s\n"
       "\tproxyknife_out=%s\n",
 	  logfilename, target.target, target.targethost, target.targetport,
 	  target.targetpath, target.key, test.httptestmethod,
 	  test.socks5testmethod, test.socks4testmethod, threads, user_agent,
 	  rcvtimeo, sndtimeo, test.testconreplysize, test.testtagreplysize,
-      proxyknife_in,proxyknife_out);
+      proxyknife_in_type,proxyknife_in,proxyknife_out);
   switch (my.mytype)
     {
       /*case DIRECT:
